Clojure only.

d-core.libs.tryable


tryablecljmacro

(tryable & body)

A macro that wraps the body in a try-catch block and returns a map with the result or error.

A macro that wraps the body in a try-catch block and returns a map with the result or error.
raw docstring

tryable!cljmacro

(tryable! & body)

A macro that wraps the body in a try-catch block and returns the result or throws the error.

A macro that wraps the body in a try-catch block and returns the result or throws the error.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries