d-core.tracing


*ctx*clj


child-ctxclj

(child-ctx ctx)

Create a child ctx under the given ctx (or a new root ctx if nil).

Create a child ctx under the given ctx (or a new root ctx if nil).
raw docstring

decode-ctxclj

(decode-ctx s)

Decode ctx from a string like: t=...;s=...;p=... Returns nil when parsing fails.

Decode ctx from a string like: t=...;s=...;p=...
Returns nil when parsing fails.
raw docstring

encode-ctxclj

(encode-ctx {:keys [trace-id span-id parent-span-id]})

Encode ctx into a compact string suitable for headers and metadata.

Encode ctx into a compact string suitable for headers and metadata.
raw docstring

ensure-ctxclj

(ensure-ctx ctx)

Ensure we have a base context. Creates a root ctx if nil.

Ensure we have a base context. Creates a root ctx if nil.
raw docstring

new-span-idclj

(new-span-id)

Short span id for a single hop.

Short span id for a single hop.
raw docstring

new-trace-idclj

(new-trace-id)

Short trace id for an entire request history.

Short trace id for an entire request history.
raw docstring

with-ctxcljmacro

(with-ctx ctx & body)

Bind tracing context for the duration of body.

Bind tracing context for the duration of body.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries