(acquire! this election-id opts)Try to acquire leadership for an election. Returns map with :status in #{:acquired :busy}.
Try to acquire leadership for an election. Returns map with :status in #{:acquired :busy}.
(renew! this election-id token opts)Renew leadership using the opaque token returned by acquire!/renew!. Returns map with :status in #{:renewed :lost}.
Renew leadership using the opaque token returned by acquire!/renew!. Returns map with :status in #{:renewed :lost}.
(resign! this election-id token opts)Release leadership using the opaque token returned by acquire!/renew!. Returns map with :status in #{:released :not-owner}.
Release leadership using the opaque token returned by acquire!/renew!. Returns map with :status in #{:released :not-owner}.
(status this election-id opts)Return current leadership state for an election. Returns map with :status in #{:vacant :held}.
Return current leadership state for an election. Returns map with :status in #{:vacant :held}.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |