(tryable & body)A macro that wraps the body in a try-catch block and returns a map with the result or error.
A macro that wraps the body in a try-catch block and returns a map with the result or error.
(tryable! & body)A macro that wraps the body in a try-catch block and returns the result or throws the error.
A macro that wraps the body in a try-catch block and returns the result or throws the error.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |