(child-ctx ctx)Create a child ctx under the given ctx (or a new root ctx if nil).
Create a child ctx under the given ctx (or a new root ctx if nil).
(decode-ctx s)Decode ctx from a string like: t=...;s=...;p=... Returns nil when parsing fails.
Decode ctx from a string like: t=...;s=...;p=... Returns nil when parsing fails.
(encode-ctx {:keys [trace-id span-id parent-span-id]})Encode ctx into a compact string suitable for headers and metadata.
Encode ctx into a compact string suitable for headers and metadata.
(ensure-ctx ctx)Ensure we have a base context. Creates a root ctx if nil.
Ensure we have a base context. Creates a root ctx if nil.
(new-span-id)Short span id for a single hop.
Short span id for a single hop.
(new-trace-id)Short trace id for an entire request history.
Short trace id for an entire request history.
(with-ctx ctx & body)Bind tracing context for the duration of body.
Bind tracing context for the duration of body.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |